@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.44';
+  $CPAN::Perl::Releases::VERSION = '0.46';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -248,6 +248,10 @@ our $data =
     "tar.bz2" => "C/CO/CORION/perl-5.15.8.tar.bz2",
     "tar.gz" => "C/CO/CORION/perl-5.15.8.tar.gz",
   },
+  "5.15.9" => {
+    "tar.bz2" => "A/AB/ABIGAIL/perl-5.15.9.tar.bz2",
+    "tar.gz" => "A/AB/ABIGAIL/perl-5.15.9.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -356,7 +360,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.44
+version 0.46
 
 =head1 SYNOPSIS
 
